flutter_zoom_view library

Classes

CameraShareView
View
getting native View from Zoom Android or iOS native SDK
WhiteboardView
A widget that embeds the Zoom whiteboard view. Place this widget in your widget tree where you want the whiteboard to appear. The whiteboard is automatically subscribed when the widget is created and unsubscribed when it is removed from the tree.
ZoomView
Define parameters that needed by Zoom native view