EventType class

Enum of ZoomVideoSdk Event

Constructors

EventType()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

onAnnotationHelperCleanUp → const String
THe event when the annotation helper clean up.
onAnnotationPrivilegeChange → const String
The event when the annotation privilege of the user has changed.
- data: {shareAction: ZoomVideoSdkShareAction, shareOwner: ZoomVideoSdkUser}
onAudioLevelChanged → const String
The event when the user's audio level changes.
- data: {user: ZoomVideoSdkUser, level: int, audioSharing: bool}
onBroadcastMessageFromMainSession → const String
The event when the user receives a broadcast message from main session.
- data: {message: String, name: String}
onCallCRCDeviceStatusChanged → const String
The event when the CRC device status changes.
- data: {status: ZoomVideoSDKCRCCallStatus}
onCalloutJoinSuccess → const String
The event when the callout user successfully joins the session.
- data: {user: ZoomVideoSdkUser, phoneNumber: String}
onCameraControlRequestResult → const String
The event when the current user is granted camera control access. Once the current user sends the camera control request, this callback will be triggered with the result of the request.
- data: {user: ZoomVideoSdkUser, approved: bool}
onChatDeleteMessageNotify → const String
The event when the meeting is deleted
- data: {msgID: String, type: ChatMessageDeleteType}
onChatNewMessageNotify → const String
The event when there is a new chat message.
- data: {message: ZoomVideoSdkChatMessage}
onChatPrivilegeChanged → const String
The event when the chat privilege of the user has changed.
- data: {privilege: ChatPrivilegeType}
onCloudRecordingStatus → const String
The event when cloud recording status has paused, stopped, resumed, or otherwise changed.
- data: {status: RecordingStatus}
onCommandChannelConnectResult → const String
The event when the command channel is connected.
- data: {success: bool}
onCommandReceived → const String
The event when receiving a message, data, or a command from the command channel.
- data: {sender: ZoomVideoSdkUser, command: String}
onError → const String
The event when there is an error.
- data: {errorType: Errors}
onHostAskUnmute → const String
The event when the host requests you to unmute yourself.
onInviteByPhoneStatus → const String
The event when the invite by phone status changes to any other valid status such as Calling, Ringing, Success, or Failed.
- data: {status: PhoneStatus}
onLiveStreamStatusChanged → const String
The event when the live stream status changes.
- data: {status: LiveStreamStatus}
onLiveTranscriptionMsgError → const String
The event when a live translation error occurs.
- data: {spokenLanguage: ZoomVideoSdkLiveTranscriptionLanguage, transcriptLanguage: ZoomVideoSdkLiveTranscriptionLanguage}
onLiveTranscriptionMsgInfoReceived → const String
The event when a live translation message is received.
- data: {messageInfo: ZoomVideoSdkLiveTranscriptionMessageInfo}
onLiveTranscriptionStatus → const String
The event when live transcription status changes.
- data: {status: LiveTranscriptionStatus}
onMicSpeakerVolumeChanged → const String
The event of the mic speaker volume changed.
- data: {micVolume: int, speakerVolume: int}
onMultiCameraStreamStatusChanged → const String
The event when someone in a given session enables or disables multi-camera. All participants in the session receive this callback.
- data: {status: MultiCameraStreamStatus, user: ZoomVideoSdkUser}
onMyAudioSourceTypeChanged → const String
The event when the audio source type of the current user changes.
- data: {device: ZoomVideoSdkAudioDevice}
onOriginalLanguageMsgReceived → const String
The event when the original language message received.
- data: {messageInfo: ZoomVideoSdkLiveTranscriptionMessageInfo}
onProxySettingNotification → const String
The event when the proxy setting is changed.
- data: {proxyHost: String, proxyPort: int, proxyDescription: String}
onQOSStatisticsReceived → const String
The event when real-time QoS statistics are available (send or receive), covering audio, video, and share streams.
- data: {statistics: ZoomVideoSdkQOSStatistics, user: ZoomVideoSdkUser?}
Note: user is null for statistics about the local user.
onRequireSystemPermission → const String
The event when the SDK requires system permissions to continue functioning.
- data: {permissionType:SystemPermissionType}
onSessionJoin → const String
The event when the session is joined.
- data: {sessionUser: ZoomVideoSdkUser}
onSessionLeave → const String
The event when the session is left.
- data: {reason: SessionLeaveReason}
onSessionNeedPassword → const String
The event when the session password is required.
onSessionPasswordWrong → const String
The event when the session password is wrong.
onShareCanvasSubscribeFail → const String
The event for the subscribed user's share view failure reason.
- data: {user: ZoomVideoSdkUser, shareAction: ZoomVideoSdkShareAction}
onShareContentChanged → const String
The event when a user makes changes to their share content type, such as switching camera share to normal share.
- data: {user: ZoomVideoSdkUser, shareAction: ZoomVideoSdkShareAction}
onShareContentSizeChanged → const String
The event when the share content size has changed.
- data: {user: ZoomVideoSdkUser, shareAction: ZoomVideoSdkShareAction}
onSpotlightVideoChanged → const String
The event when the spotlight videos change.
- data: {changedUsers: List<ZoomVideoSdkUser>}
onSSLCertVerifiedFailNotification → const String
The event when the SSL is verified.
- data: {certIssuedTo: String, certIssuedBy: String, certSerialNum: String, certFingerPrint: String}
onSubSessionManagerHandle → const String
The event when the user receives subsession manager privilege.
onSubSessionParticipantHandle → const String
The event when the user receives subsession attendee privilege.
onSubSessionStatusChanged → const String
The event when the subsession status changes.
- data: {status: SubSessionStatus, subSessions: List<ZoomVideoSdkSubSessionKit>}
onSubSessionUserHelpRequestHandler → const String
The event when the user receives a help request from subsession.
onSubSessionUserHelpRequestResult → const String
The event when the result of help request is received.
- data: {result: UserHelpRequestResult}
onSubSessionUsersUpdate → const String
The event when the users of a subsession are updated.
- data: {subSession: ZoomVideoSdkSubSessionKit}
onTestMicStatusChanged → const String
The event of the test mic status changed.
- data: {status: TestMicStatus}
onUserActiveAudioChanged → const String
The event when the user's active audio changes.
- data: {changedUsers: List<ZoomVideoSdkUser>}
onUserAudioStatusChanged → const String
The event when the users' audio status changes.
- data: {changedUsers: List<ZoomVideoSdkUser>}
onUserHostChanged → const String
THe event when the session host changes.
- data: {changedUser: ZoomVideoSdkUser}
onUserJoin → const String
The event when the user joins the session.
- data: {user: ZoomVideoSdkUser}
onUserLeave → const String
The event when the user leaves the session.
- data: {user: ZoomVideoSdkUser}
onUserManagerChanged → const String
The event when the session manager changes.
- data: {changedUser: ZoomVideoSdkUser}
onUserNameChanged → const String
The event when the user's name changes.
- data: {changedUser: ZoomVideoSdkUser}
onUserNetworkStatusChanged → const String
The event when the user's network status changes.
- data: {user: ZoomVideoSdkUser, level: NetworkStatus, type: DataType}
onUserOverallNetworkStatusChanged → const String
The event when the user's overall network status changes.
- data: {user: ZoomVideoSdkUser, level: NetworkStatus}
onUserRecordingConsent → const String
The event when a user consent to individual recording.
- data: {user: ZoomVideoSdkUser}
onUserShareStatusChanged → const String
The event when the user's share status changes.
- data: {user: ZoomVideoSdkUser, shareAction: ZoomVideoSdkShareAction}
onUserVideoNetworkStatusChanged → const String
The event when the user's video network status changes.
- data: {user: ZoomVideoSdkUser, status: NetworkStatus}
onUserVideoStatusChanged → const String
The event when the users' video status changes.
- data: {changedUsers: List<ZoomVideoSdkUser>}
onUserWhiteboardShareStatusChanged → const String
The event when the whiteboard share status of a user changes.
- data: {user: ZoomVideoSdkUser, status: WhiteboardStatus}
onUVCCameraStatusChange → const String
The event of the UVCCamera status change.
- data: {status: UVCCameraStatus}
onVideoCanvasSubscribeFail → const String
The event of subscribe user's video fail reason.
- data: {user: ZoomVideoSdkUser, failReason: SubscribeFailReason}
onWhiteboardExported → const String
The event when the whiteboard is exported.
- data: {format: ExportFormat, data: String}