ZoomVideoSdkEventListener class

Constructors

ZoomVideoSdkEventListener()

Properties

eventChannel EventChannel
The event channel used to interact with the native platform.
final
eventEmitter ↔ EventEmitter
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(String event, void handler(dynamic data)) StreamSubscription
Add a listener to the event.
- event: EventType The event to listen to.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited