ZoomVideoSdkUser class

Zoom Video SDK User

Constructors

ZoomVideoSdkUser(String userId, String customUserId, String userName, bool isHost, bool isManager, bool isVideoSpotLighted, bool? hasMultiCamera, String? multiCameraIndex, bool isSharing)
ZoomVideoSdkUser.fromJson(Map<String, dynamic> json)

Properties

audioStatus ZoomVideoSdkAudioStatus?
the index of the multiple cameras
getter/setter pair
customUserId String
the identify of the user
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasMultiCamera bool?
true: if the user is video spot lighted
getter/setter pair
isHost bool
the name of the user
getter/setter pair
isManager bool
true: if the user is the host of the session
getter/setter pair
isSharing bool
true: if the user is the manager of the session
getter/setter pair
isVideoSpotLighted bool
true: if the user is sharing
getter/setter pair
methodChannel MethodChannel
the share statistic information of the user
final
multiCameraIndex String?
true: if the user has multiple cameras
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shareStatisticInfo ZoomVideoSdkShareStatisticInfo?
the video statistic information of the user
getter/setter pair
userId String
getter/setter pair
userName String
the custom identify of the user
getter/setter pair
videoStatisticInfo ZoomVideoSdkVideoStatisticInfo?
the video status of the user
getter/setter pair
videoStatus ZoomVideoSdkVideoStatus?
the audio status of the user
getter/setter pair

Methods

canSetUserPlaybackVolume(String userId, bool isSharingAudio) Future<bool>
Determine whether the user's playback volume can be set.
userId the identify of the user
isSharingAudio true to check whether shared audio playback volume can be set; false to check microphone playback volume.
Return true if the playback volume can be set, otherwise false.
canSetUserVolume(String userId, bool isShareAudio) Future<bool>
Determine which audio you can set, shared audio or microphone.
userId the identify of the user
isShareAudio true: if the user is sharing audio, otherwise false
Return true if can set user volume, otherwise false
getIsHost() Future<bool>
Determine whether the user is the host.
Return true indicates that the user is the host, otherwise false.
getIsManager() Future<bool>
Determine whether the user is the manager.
Return true indicates that the user is the manager, otherwise false.
getIsVideoSpotLighted() Future<bool>
Determine whether the user's video is spotlighted.
Return true indicates that the user's video is spotlighted, otherwise false.
getNetworkLevel(String dataType) Future<String>
Get the network status by dataType of the user in the session.
Return the network status of the user in the session.
getOverallNetworkLevel() Future<String>
Get the overall network status of the user in the session.
Return the overall network status of the user in the session.
getShareActionList() Future<List<ZoomVideoSdkShareAction>?>
getShareStatus() Future<String>
Get the user's screen share status.
Return the share status of the user in the session.
getUserName() Future<String>
Get the name of the user in the session.
Return the name of the user in the session.
getUserPlaybackVolume(String userId, bool isSharingAudio) Future<num>
Get the user's local playback volume.
userId the identify of the user
isSharingAudio true to get the volume of shared audio; false to get the microphone volume.
Return the volume, or -1 if it could not be read.
getUserReference() Future<String>
Get the GUID of the user in the session.
Return the GUID of the user in the session.
getUserVolume(String userId, bool isShareAudio) Future<num>
Get user volume.
userId the identify of the user
isShareAudio true: if the user is sharing audio, otherwise false
Return user volume.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setUserPlaybackVolume(String userId, num volume, bool isSharingAudio) Future<bool>
Set the user's local playback volume. This does not affect how other participants hear the user.
userId the identify of the user
volume the volume value, must be in 0, 10. 0 mutes the related audio.
isSharingAudio true to set the volume of shared audio (such as shared computer audio); false to set the microphone volume.
Return true if the call succeeds, otherwise false.
setUserVolume(String userId, num volume, bool isShareAudio) Future<bool>
Set the user's local volume. This does not affect how other participants hear the user.
userId the identify of the user
volume the volume of the user
isShareAudio true: if the user is sharing audio, otherwise false
Return true the methods succeeds, otherwise false.
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited