getShareStatus method
Get the user's screen share status.
Return the share status of the user in the session.
Implementation
@Deprecated("Use [getShareActionList] instead")
Future<String> getShareStatus() async {
return "";
}
Get the user's screen share status.
Return the share status of the user in the session.
@Deprecated("Use [getShareActionList] instead")
Future<String> getShareStatus() async {
return "";
}