ZoomVideoSdkVideoStatisticInfo class
Zoom Video SDK Video Statistic Information
- Inheritance
-
- Object
- PlatformInterface
- ZoomVideoSdkVideoStatisticInfoPlatform
- ZoomVideoSdkVideoStatisticInfo
Constructors
- ZoomVideoSdkVideoStatisticInfo(String userId)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → String
-
final
Methods
-
getBpf(
) → Future< num> -
Get the video's bit rate.
Return the video's bit rate.override -
getFps(
) → Future< num> -
Get the video's Frames Per Second (FPS).
Return the video's Frames Per Second (FPS).override -
getHeight(
) → Future< num> -
Get the video's frame height in pixels.
Return the video's frame height in pixels.override -
getQoSStatistics(
) → Future< ZoomVideoSdkQOSStatistics?> -
Get the full video QoS statistics for this user, including the new
fields introduced in Zoom Video SDK 2.5.x (codec, rtt, jitter,
packets, bandwidth, avg/max packet loss, etc.).
Return a ZoomVideoSdkQOSStatistics object, or null if the underlying SDK has no statistics available.override -
getWidth(
) → Future< num> -
Get the video's frame height in pixels.
Return the video's frame height in pixels.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited