ZoomVideoSdkQOSStatistics class
Zoom Video SDK QoS (Quality of Service) statistics for media streams (Audio, Video, Share).
Common fields are always populated. Send/Receive specific fields are populated based on direction:
- When direction is ZoomVideoSdkStatisticsDirection.send, the send-specific fields (frameWidthInput, framesEncoded, etc.) are populated.
- When direction is ZoomVideoSdkStatisticsDirection.receive, the receive-specific fields (bytesReceived, framesDecoded, etc.) are populated.
Constructors
- ZoomVideoSdkQOSStatistics({required String direction, required num timestamp, required String? codecName, required num rtt, required num jitter, required num width, required num height, required num fps, required num bps, required num? bpf, required num bytesTransferred, required num packetsLost, required num packetsTransferred, required String networkLevel, required String statisticsType, required num avgLoss, required num maxLoss, required num bandwidth, num? frameWidthInput, num? frameHeightInput, num? frameRateInput, num? totalPacketSendDelay, num? totalEncodeTime, num? framesEncoded, num? bytesReceived, num? packetsReceived, num? estimatedPlayoutTimestamp, num? totalDecodeTime, num? framesDecoded, num? jitterBufferDelay, num? jitterBufferEmittedCount})
-
ZoomVideoSdkQOSStatistics.fromJson(Map<
String, dynamic> json)
Properties
- avgLoss ↔ num
-
Average packet loss ratio in per thousand (e.g. 100 means 10%).
getter/setter pair
- bandwidth ↔ num
-
Estimated bandwidth in bps.
getter/setter pair
- bpf ↔ num?
-
Bits per frame. Android only; null on iOS.
getter/setter pair
- bps ↔ num
-
Bits per second.
getter/setter pair
- bytesReceived ↔ num?
-
Total bytes received. Receive only — null otherwise.
getter/setter pair
- bytesTransferred ↔ num
-
Total bytes transferred (sent or received per direction).
getter/setter pair
- codecName ↔ String?
-
The codec name. For video/share: "h264", "av1". For audio: "silk",
"opus", "pcm", "G722", "G729".
getter/setter pair
- direction ↔ String
-
The direction of statistics (send or receive).
getter/setter pair
- estimatedPlayoutTimestamp ↔ num?
-
Estimated playout timestamp. Receive only — null otherwise.
getter/setter pair
- fps ↔ num
-
Frame rate in FPS (sent or received per direction).
getter/setter pair
- frameHeightInput ↔ num?
-
Height of the input frame. Send only — null otherwise.
getter/setter pair
- frameRateInput ↔ num?
-
Frame rate of input. Send only — null otherwise.
getter/setter pair
- framesDecoded ↔ num?
-
Total number of frames decoded. Receive only — null otherwise.
getter/setter pair
- framesEncoded ↔ num?
-
Total number of frames encoded. Send only — null otherwise.
getter/setter pair
- frameWidthInput ↔ num?
-
Width of the input frame. Send only — null otherwise.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- height ↔ num
-
Frame height (sent or received per direction).
getter/setter pair
- jitter ↔ num
-
The jitter in milliseconds.
getter/setter pair
- jitterBufferDelay ↔ num?
-
Jitter buffer delay in milliseconds. Receive only — null otherwise.
getter/setter pair
- jitterBufferEmittedCount ↔ num?
-
Number of samples emitted from jitter buffer. Receive only — null otherwise.
getter/setter pair
- maxLoss ↔ num
-
Maximum packet loss ratio in per thousand (e.g. 100 means 10%).
getter/setter pair
- networkLevel ↔ String
-
Network quality level. One of the ZoomVideoSDKNetwork_* constants.
getter/setter pair
- packetsLost ↔ num
-
Number of packets lost during transmission.
getter/setter pair
- packetsReceived ↔ num?
-
Total number of packets received. Receive only — null otherwise.
getter/setter pair
- packetsTransferred ↔ num
-
Total number of packets transferred (sent or received per direction).
getter/setter pair
- rtt ↔ num
-
The round-trip time in milliseconds.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statisticsType ↔ String
-
Statistics type (Audio, Video, or Share). One of the
ZoomVideoSDKDataType_* constants.
getter/setter pair
- timestamp ↔ num
-
The timestamp of the statistics.
getter/setter pair
- totalDecodeTime ↔ num?
-
Total time spent decoding in milliseconds. Receive only — null otherwise.
getter/setter pair
- totalEncodeTime ↔ num?
-
Total time spent encoding in milliseconds. Send only — null otherwise.
getter/setter pair
- totalPacketSendDelay ↔ num?
-
Total packet send delay in milliseconds. Send only — null otherwise.
getter/setter pair
- width ↔ num
-
Frame width (sent or received per direction).
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited