ZoomVideoSdkVideoSettingHelper class
Video setting helper for managing video settings such as face beauty effects.
- Inheritance
-
- Object
- PlatformInterface
- ZoomVideoSdkVideoSettingHelper
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
enableFaceBeautyEffect(
bool enable) → Future< String> -
Enable or disable the face beauty effect.
enabletrue to enable the face beauty effect, false to disable it.
ReturnZoomVideoSDKError_Successif the function succeeds. Otherwise, this function returns an error. -
getFaceBeautyStrengthValue(
) → Future< int> -
Get the current face beauty strength value.
Return the current face beauty strength value (0-100). -
isFaceBeautyEffectEnabled(
) → Future< bool> -
Check whether the face beauty effect is enabled.
Return true if the face beauty effect is enabled, otherwise false. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setFaceBeautyStrengthValue(
int strengthValue) → Future< String> -
Set the strength of the face beauty effect.
strengthValueThe face beauty strength value (0-100).
ReturnZoomVideoSDKError_Successif the function succeeds. Otherwise, this function returns an error. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited